@@ -52,6 +52,13 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         """
         return MVPolyCube(**kwd)
 
+    @classmethod
+    def one(self, **kwd) :
+        """
+        Return the unit (1) polynomial.
+        """
+        return MVPolyCube(1, **kwd)
+
     def dtype_set_callback(self, value) :
         """
         For internal use. Sets the datatype of the 
@@ -137,26 +144,29 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         """
         return ((self - other).coef == 0).all()
 
-    def order(self) :
+    @property
+    def degrees(self) :
         """
-        Return the maximal order of each of the variables of
-        the polynomial as a tuple of integers. For the zero 
-        polynomial, returns the empty tuple.
+        Return the maximal degree of each of the variables of
+        the polynomial as a tuple of integers. For a constant
+        (including a zero) polynomial, returns the empty tuple.
         """
         if self.coef.any() :
             return tuple(n-1 for n in self.coef.shape) 
         else :
             return ()
 
-    def homdeg(self) :
+    @property
+    def degree(self) :
         """
-        The *homogeneous degree*, the maximal sum of the
+        The (total, homogeneous) *degree*, the maximal sum of the
         monomial degrees of monomials with nonzero coefficients. 
+        Returns -1 for the zero polynomial.
         """
         nzis = np.nonzero(self.coef)
         degs = [sum(t) for t in zip(*nzis)]
         if not degs :
-            raise ValueError("homogeneous degree undefined for zero polynomial")
+            return -1
         return np.max(degs)
 
     def eval(self, *args) :
